@@ -245,8 +245,8 @@ croston2 <- function(x,h=10,alpha=0.1,nofits=FALSE)
         return(rep(y/tt,h))
     else if(length(y)<=1 | length(tt)<=1)
         return(rep(NA,h))
-    y.f <- forecast(HoltWinters(y,beta=0,gamma=0,alpha=alpha),h=h)
-    p.f <- forecast(HoltWinters(tt,beta=0,gamma=0,alpha=alpha),h=h)
+    y.f <- forecast(HoltWinters(y,beta=FALSE,gamma=FALSE,alpha=alpha),h=h)
+    p.f <- forecast(HoltWinters(tt,beta=FALSE,gamma=FALSE,alpha=alpha),h=h)
     if(nofits)
         return(y.f$mean/p.f$mean)
     else
